import {
  Component,
  OnInit,
  Input,
  Output,
  EventEmitter,
  ViewChild,
  ChangeDetectorRef,
  Renderer2
} from '@angular/core';
import { ucapAnimations } from '../animations';
import { UserInfoSS } from '@ucap-webmessenger/protocol-query';
import { MatPaginator, PageEvent, MatTabLabel } from '@angular/material';

@Component({
  selector: 'ucap-integrated-search',
  templateUrl: './integrated-search.component.html',
  styleUrls: ['./integrated-search.component.scss'],
  animations: ucapAnimations
})
export class IntegratedSearchComponent implements OnInit {
  @Input()
  searchWord?: string;
  @Input()
  searchingProcessing: boolean;
  @Input()
  searchUserInfos: UserInfoSS[] = [];
  @Input()
  totalCount = 0;
  @Input()
  pageCurrent = 1;
  @Input()
  pageListCount = 20;

  @Output()
  search = new EventEmitter<string>();
  @Output()
  changePage = new EventEmitter<PageEvent>();

  @ViewChild(MatPaginator, { static: true }) paginator: MatPaginator;
  displayedColumns: string[] = [
    'profile',
    'name',
    'deptName',
    'companyName',
    'grade',
    'lineNumber',
    'hpNumber',
    'email',
    'responsibilities',
    'workplace'
  ];

  start: any = undefined;
  pressed = false;
  startX: any;
  startWidth: any;
  resizableFnMousemove: () => void;
  resizableFnMouseup: () => void;

  constructor(
    private changeDetectorRef: ChangeDetectorRef,
    private renderer: Renderer2
  ) {}

  ngOnInit() {}

  onSearch(keyword: string) {
    this.search.emit(keyword);
  }

  onChangePage(event: PageEvent) {
    this.changePage.emit(event);
  }

  resizeTable(event: any, column: any) {
    this.start = event.target;
    this.pressed = true;
    this.startX = event.pageX;
    this.startWidth = this.start.clientWidth;
    this.mouseMove(column);
  }

  mouseMove(column: any) {
    this.resizableFnMousemove = this.renderer.listen(
      'document',
      'mousemove',
      event => {
        if (this.pressed) {
          let width = this.startWidth + (event.pageX - this.startX);
          let index = this.start.cellIndex;
          column.width = width;
        }
      }
    );
    this.resizableFnMouseup = this.renderer.listen(
      'document',
      'mouseup',
      event => {
        if (this.pressed) {
          this.pressed = false;
          this.resizableFnMousemove();
          this.resizableFnMouseup();
        }
      }
    );
  }
}
